[clikt](../index.md) / [com.github.ajalt.clikt.parameters.arguments](./index.md)

## Package com.github.ajalt.clikt.parameters.arguments

### Types

| Name | Summary |
|---|---|
| [Argument](-argument/index.md) | `interface Argument`<br>A positional parameter to a command. |
| [ArgumentDelegate](-argument-delegate/index.md) | `interface ArgumentDelegate<out T> : `[`Argument`](-argument/index.md)`, `[`ReadOnlyProperty`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.properties/-read-only-property/index.html)`<`[`CliktCommand`](../com.github.ajalt.clikt.core/-clikt-command/index.md)`, `[`T`](-argument-delegate/index.md#T)`>`<br>An argument that functions as a property delegate |
| [ArgumentTransformContext](-argument-transform-context/index.md) | `class ArgumentTransformContext : `[`Argument`](-argument/index.md)<br>A receiver for argument transformers. |
| [ProcessedArgument](-processed-argument/index.md) | `class ProcessedArgument<AllT, ValueT> : `[`ArgumentDelegate`](-argument-delegate/index.md)`<`[`AllT`](-processed-argument/index.md#AllT)`>`<br>An [Argument](-argument/index.md) delegate implementation that transforms its values . |

### Type Aliases

| Name | Summary |
|---|---|
| [ArgCallsTransformer](-arg-calls-transformer.md) | `typealias ArgCallsTransformer<AllT, EachT> = `[`ArgumentTransformContext`](-argument-transform-context/index.md)`.(`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EachT`](-arg-calls-transformer.md#EachT)`>) -> `[`AllT`](-arg-calls-transformer.md#AllT)<br>A callback that transforms all the values into the final argument type |
| [ArgValidator](-arg-validator.md) | `typealias ArgValidator<AllT> = `[`ArgumentTransformContext`](-argument-transform-context/index.md)`.(`[`AllT`](-arg-validator.md#AllT)`) -> `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)<br>A callback validates the final argument type |
| [ArgValueTransformer](-arg-value-transformer.md) | `typealias ArgValueTransformer<T> = `[`ArgumentTransformContext`](-argument-transform-context/index.md)`.(`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`) -> `[`T`](-arg-value-transformer.md#T)<br>A callback that transforms a single value from a string to the value type |

### Functions

| Name | Summary |
|---|---|
| [argument](argument.md) | `fun `[`CliktCommand`](../com.github.ajalt.clikt.core/-clikt-command/index.md)`.argument(name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "", help: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "", helpTags: `[`Map`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`> = emptyMap()): RawArgument`<br>Create a property delegate argument. |
| [convert](convert.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> RawArgument.convert(completionCandidates: `[`CompletionCandidates`](../com.github.ajalt.clikt.completion/-completion-candidates/index.md)` = this.completionCandidates, conversion: `[`ArgValueTransformer`](-arg-value-transformer.md)`<`[`T`](convert.md#T)`>): `[`ProcessedArgument`](-processed-argument/index.md)`<`[`T`](convert.md#T)`, `[`T`](convert.md#T)`>`<br>Convert the argument's values. |
| [default](default.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`T`](default.md#T)`, `[`T`](default.md#T)`>.default(value: `[`T`](default.md#T)`): `[`ArgumentDelegate`](-argument-delegate/index.md)`<`[`T`](default.md#T)`>`<br>If the argument is not given, use [value](default.md#com.github.ajalt.clikt.parameters.arguments$default(com.github.ajalt.clikt.parameters.arguments.ProcessedArgument((com.github.ajalt.clikt.parameters.arguments.default.T, )), com.github.ajalt.clikt.parameters.arguments.default.T)/value) instead of throwing an error. |
| [defaultLazy](default-lazy.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`T`](default-lazy.md#T)`, `[`T`](default-lazy.md#T)`>.defaultLazy(value: () -> `[`T`](default-lazy.md#T)`): `[`ArgumentDelegate`](-argument-delegate/index.md)`<`[`T`](default-lazy.md#T)`>`<br>If the argument is not given, call [value](default-lazy.md#com.github.ajalt.clikt.parameters.arguments$defaultLazy(com.github.ajalt.clikt.parameters.arguments.ProcessedArgument((com.github.ajalt.clikt.parameters.arguments.defaultLazy.T, )), kotlin.Function0((com.github.ajalt.clikt.parameters.arguments.defaultLazy.T)))/value) and use its return value instead of throwing an error. |
| [multiple](multiple.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`T`](multiple.md#T)`, `[`T`](multiple.md#T)`>.multiple(required: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false): `[`ProcessedArgument`](-processed-argument/index.md)`<`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`T`](multiple.md#T)`>, `[`T`](multiple.md#T)`>`<br>Accept any number of values to this argument. |
| [optional](optional.md) | `fun <AllT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`AllT`](optional.md#AllT)`, `[`ValueT`](optional.md#ValueT)`>.optional(): `[`ProcessedArgument`](-processed-argument/index.md)`<`[`AllT`](optional.md#AllT)`?, `[`ValueT`](optional.md#ValueT)`>`<br>Return null instead of throwing an error if no value is given. |
| [pair](pair.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`T`](pair.md#T)`, `[`T`](pair.md#T)`>.pair(): `[`ProcessedArgument`](-processed-argument/index.md)`<`[`Pair`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html)`<`[`T`](pair.md#T)`, `[`T`](pair.md#T)`>, `[`T`](pair.md#T)`>`<br>Require exactly two values to this argument, and store them in a [Pair](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html). |
| [transformAll](transform-all.md) | `fun <AllInT, ValueT, AllOutT> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`AllInT`](transform-all.md#AllInT)`, `[`ValueT`](transform-all.md#ValueT)`>.transformAll(nvalues: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`? = null, required: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`? = null, transform: `[`ArgCallsTransformer`](-arg-calls-transformer.md)`<`[`AllOutT`](transform-all.md#AllOutT)`, `[`ValueT`](transform-all.md#ValueT)`>): `[`ProcessedArgument`](-processed-argument/index.md)`<`[`AllOutT`](transform-all.md#AllOutT)`, `[`ValueT`](transform-all.md#ValueT)`>`<br>Transform all values to the final argument type. |
| [triple](triple.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`T`](triple.md#T)`, `[`T`](triple.md#T)`>.triple(): `[`ProcessedArgument`](-processed-argument/index.md)`<`[`Triple`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-triple/index.html)`<`[`T`](triple.md#T)`, `[`T`](triple.md#T)`, `[`T`](triple.md#T)`>, `[`T`](triple.md#T)`>`<br>Require exactly three values to this argument, and store them in a [Triple](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-triple/index.html) |
| [unique](unique.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`T`](unique.md#T)`>, `[`T`](unique.md#T)`>.unique(): `[`ProcessedArgument`](-processed-argument/index.md)`<`[`Set`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)`<`[`T`](unique.md#T)`>, `[`T`](unique.md#T)`>`<br>Only store unique values for this argument |
| [validate](validate.md) | `fun <AllT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`ProcessedArgument`](-processed-argument/index.md)`<`[`AllT`](validate.md#AllT)`, `[`ValueT`](validate.md#ValueT)`>.validate(validator: `[`ArgValidator`](-arg-validator.md)`<`[`AllT`](validate.md#AllT)`>): `[`ArgumentDelegate`](-argument-delegate/index.md)`<`[`AllT`](validate.md#AllT)`>`<br>Check the final argument value and raise an error if it's not valid. |
