[clikt](../index.md) / [com.github.ajalt.clikt.parameters.options](./index.md)

## Package com.github.ajalt.clikt.parameters.options

### Types

| Name | Summary |
|---|---|
| [EagerOption](-eager-option/index.md) | `class EagerOption : `[`Option`](-option/index.md)<br>An [Option](-option/index.md) with no values that is [finalize](-eager-option/finalize.md)d before other types of options. |
| [FlagOption](-flag-option/index.md) | `class FlagOption<T> : `[`OptionDelegate`](-option-delegate/index.md)`<`[`T`](-flag-option/index.md#T)`>`<br>An [Option](-option/index.md) that has no values. |
| [Option](-option/index.md) | `interface Option`<br>An optional command line parameter that takes a fixed number of values. |
| [OptionCallTransformContext](-option-call-transform-context/index.md) | `class OptionCallTransformContext : `[`Option`](-option/index.md)<br>A receiver for options transformers. |
| [OptionDelegate](-option-delegate/index.md) | `interface OptionDelegate<T> : `[`GroupableOption`](../com.github.ajalt.clikt.core/-groupable-option/index.md)`, `[`ReadOnlyProperty`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.properties/-read-only-property/index.html)`<`[`ParameterHolder`](../com.github.ajalt.clikt.core/-parameter-holder/index.md)`, `[`T`](-option-delegate/index.md#T)`>`<br>An option that functions as a property delegate |
| [OptionTransformContext](-option-transform-context/index.md) | `class OptionTransformContext : `[`Option`](-option/index.md)<br>A receiver for options transformers. |
| [OptionWithValues](-option-with-values/index.md) | `class OptionWithValues<AllT, EachT, ValueT> : `[`OptionDelegate`](-option-delegate/index.md)`<`[`AllT`](-option-with-values/index.md#AllT)`>, `[`GroupableOption`](../com.github.ajalt.clikt.core/-groupable-option/index.md)<br>An [Option](-option/index.md) that takes one or more values. |
| [ValueWithDefault](-value-with-default/index.md) | `data class ValueWithDefault<out T>`<br>A container for a value that can have a default value and can be manually set |

### Type Aliases

| Name | Summary |
|---|---|
| [ArgsTransformer](-args-transformer.md) | `typealias ArgsTransformer<ValueT, EachT> = `[`OptionCallTransformContext`](-option-call-transform-context/index.md)`.(`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`ValueT`](-args-transformer.md#ValueT)`>) -> `[`EachT`](-args-transformer.md#EachT)<br>A callback that transforms all the values for a call to the call type. |
| [CallsTransformer](-calls-transformer.md) | `typealias CallsTransformer<EachT, AllT> = `[`OptionTransformContext`](-option-transform-context/index.md)`.(`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EachT`](-calls-transformer.md#EachT)`>) -> `[`AllT`](-calls-transformer.md#AllT)<br>A callback that transforms all of the calls to the final option type. |
| [NullableOption](-nullable-option.md) | `typealias NullableOption<EachT, ValueT> = `[`OptionWithValues`](-option-with-values/index.md)`<`[`EachT`](-nullable-option.md#EachT)`?, `[`EachT`](-nullable-option.md#EachT)`, `[`ValueT`](-nullable-option.md#ValueT)`>` |
| [OptionValidator](-option-validator.md) | `typealias OptionValidator<AllT> = `[`OptionTransformContext`](-option-transform-context/index.md)`.(`[`AllT`](-option-validator.md#AllT)`) -> `[`Unit`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-unit/index.html)<br>A callback validates the final option type |
| [RawOption](-raw-option.md) | `typealias RawOption = `[`NullableOption`](-nullable-option.md)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`>` |
| [ValueTransformer](-value-transformer.md) | `typealias ValueTransformer<ValueT> = `[`OptionCallTransformContext`](-option-call-transform-context/index.md)`.(`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`) -> `[`ValueT`](-value-transformer.md#ValueT)<br>A callback that transforms a single value from a string to the value type |

### Functions

| Name | Summary |
|---|---|
| [convert](convert.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`RawOption`](-raw-option.md)`.convert(metavar: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "VALUE", envvarSplit: `[`Regex`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.text/-regex/index.html)` = this.envvarSplit.default, completionCandidates: `[`CompletionCandidates`](../com.github.ajalt.clikt.completion/-completion-candidates/index.md)` = this.completionCandidates, conversion: `[`ValueTransformer`](-value-transformer.md)`<`[`T`](convert.md#T)`>): `[`NullableOption`](-nullable-option.md)`<`[`T`](convert.md#T)`, `[`T`](convert.md#T)`>`<br>Convert the option value type. |
| [counted](counted.md) | `fun `[`RawOption`](-raw-option.md)`.counted(): `[`FlagOption`](-flag-option/index.md)`<`[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`>`<br>Turn an option into a flag that counts the number of times the option occurs on the command line. |
| [default](default.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`FlagOption`](-flag-option/index.md)`<`[`T`](default.md#T)`?>.default(value: `[`T`](default.md#T)`): `[`FlagOption`](-flag-option/index.md)`<`[`T`](default.md#T)`>`<br>Set a default value for a option.`fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](default.md#EachT)`, `[`ValueT`](default.md#ValueT)`>.default(value: `[`EachT`](default.md#EachT)`, defaultForHelp: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = value.toString()): `[`OptionWithValues`](-option-with-values/index.md)`<`[`EachT`](default.md#EachT)`, `[`EachT`](default.md#EachT)`, `[`ValueT`](default.md#ValueT)`>`<br>If the option is not called on the command line (and is not set in an envvar), use [value](default.md#com.github.ajalt.clikt.parameters.options$default(com.github.ajalt.clikt.parameters.options.OptionWithValues((com.github.ajalt.clikt.parameters.options.default.EachT, com.github.ajalt.clikt.parameters.options.default.EachT, com.github.ajalt.clikt.parameters.options.default.ValueT)), com.github.ajalt.clikt.parameters.options.default.EachT, kotlin.String)/value) for the option. |
| [defaultLazy](default-lazy.md) | `fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](default-lazy.md#EachT)`, `[`ValueT`](default-lazy.md#ValueT)`>.defaultLazy(defaultForHelp: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "", value: () -> `[`EachT`](default-lazy.md#EachT)`): `[`OptionWithValues`](-option-with-values/index.md)`<`[`EachT`](default-lazy.md#EachT)`, `[`EachT`](default-lazy.md#EachT)`, `[`ValueT`](default-lazy.md#ValueT)`>`<br>If the option is not called on the command line (and is not set in an envvar), call the [value](default-lazy.md#com.github.ajalt.clikt.parameters.options$defaultLazy(com.github.ajalt.clikt.parameters.options.OptionWithValues((com.github.ajalt.clikt.parameters.options.defaultLazy.EachT, com.github.ajalt.clikt.parameters.options.defaultLazy.EachT, com.github.ajalt.clikt.parameters.options.defaultLazy.ValueT)), kotlin.String, kotlin.Function0((com.github.ajalt.clikt.parameters.options.defaultLazy.EachT)))/value) and use its return value for the option. |
| [deprecated](deprecated.md) | `fun <T> `[`FlagOption`](-flag-option/index.md)`<`[`T`](deprecated.md#T)`>.deprecated(message: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = "", tagName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = "deprecated", tagValue: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "", error: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false): `[`OptionDelegate`](-option-delegate/index.md)`<`[`T`](deprecated.md#T)`>`<br>`fun <AllT, EachT, ValueT> `[`OptionWithValues`](-option-with-values/index.md)`<`[`AllT`](deprecated.md#AllT)`, `[`EachT`](deprecated.md#EachT)`, `[`ValueT`](deprecated.md#ValueT)`>.deprecated(message: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = "", tagName: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = "deprecated", tagValue: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "", error: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false): `[`OptionDelegate`](-option-delegate/index.md)`<`[`AllT`](deprecated.md#AllT)`>`<br>Mark this option as deprecated in the help output. |
| [flag](flag.md) | `fun `[`RawOption`](-raw-option.md)`.flag(vararg secondaryNames: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, default: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false): `[`FlagOption`](-flag-option/index.md)`<`[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)`>`<br>Turn an option into a boolean flag. |
| [multiple](multiple.md) | `fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](multiple.md#EachT)`, `[`ValueT`](multiple.md#ValueT)`>.multiple(default: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EachT`](multiple.md#EachT)`> = emptyList()): `[`OptionWithValues`](-option-with-values/index.md)`<`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EachT`](multiple.md#EachT)`>, `[`EachT`](multiple.md#EachT)`, `[`ValueT`](multiple.md#ValueT)`>`<br>Make the option return a list of calls; each item in the list is the value of one call. |
| [option](option.md) | `fun `[`ParameterHolder`](../com.github.ajalt.clikt.core/-parameter-holder/index.md)`.option(vararg names: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, help: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "", metavar: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = null, hidden: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false, envvar: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = null, envvarSplit: `[`Regex`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.text/-regex/index.html)`? = null, helpTags: `[`Map`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`> = emptyMap()): `[`RawOption`](-raw-option.md)<br>Create a property delegate option. |
| [pair](pair.md) | `fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](pair.md#EachT)`, `[`ValueT`](pair.md#ValueT)`>.pair(): `[`NullableOption`](-nullable-option.md)`<`[`Pair`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html)`<`[`ValueT`](pair.md#ValueT)`, `[`ValueT`](pair.md#ValueT)`>, `[`ValueT`](pair.md#ValueT)`>`<br>Change to option to take two values, held in a [Pair](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html). |
| [prompt](prompt.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`NullableOption`](-nullable-option.md)`<`[`T`](prompt.md#T)`, `[`T`](prompt.md#T)`>.prompt(text: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = null, default: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = null, hideInput: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false, requireConfirmation: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = false, confirmationPrompt: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "Repeat for confirmation: ", promptSuffix: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = ": ", showDefault: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = true): `[`OptionWithValues`](-option-with-values/index.md)`<`[`T`](prompt.md#T)`, `[`T`](prompt.md#T)`, `[`T`](prompt.md#T)`>`<br>If the option isn't given on the command line, prompt the user for manual input. |
| [required](required.md) | `fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](required.md#EachT)`, `[`ValueT`](required.md#ValueT)`>.required(): `[`OptionWithValues`](-option-with-values/index.md)`<`[`EachT`](required.md#EachT)`, `[`EachT`](required.md#EachT)`, `[`ValueT`](required.md#ValueT)`>`<br>If the option is not called on the command line (and is not set in an envvar), throw a [MissingParameter](../com.github.ajalt.clikt.core/-missing-parameter/index.md). |
| [split](split.md) | `fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](split.md#EachT)`, `[`ValueT`](split.md#ValueT)`>.split(regex: `[`Regex`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.text/-regex/index.html)`): `[`OptionWithValues`](-option-with-values/index.md)`<`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`ValueT`](split.md#ValueT)`>?, `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`ValueT`](split.md#ValueT)`>, `[`ValueT`](split.md#ValueT)`>`<br>Change to option to take any number of values, separated by a [regex](split.md#com.github.ajalt.clikt.parameters.options$split(com.github.ajalt.clikt.parameters.options.OptionWithValues((com.github.ajalt.clikt.parameters.options.split.EachT, com.github.ajalt.clikt.parameters.options.split.EachT, com.github.ajalt.clikt.parameters.options.split.ValueT)), kotlin.text.Regex)/regex).`fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](split.md#EachT)`, `[`ValueT`](split.md#ValueT)`>.split(delimiter: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`): `[`OptionWithValues`](-option-with-values/index.md)`<`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`ValueT`](split.md#ValueT)`>?, `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`ValueT`](split.md#ValueT)`>, `[`ValueT`](split.md#ValueT)`>`<br>Change to option to take any number of values, separated by a string [delimiter](split.md#com.github.ajalt.clikt.parameters.options$split(com.github.ajalt.clikt.parameters.options.OptionWithValues((com.github.ajalt.clikt.parameters.options.split.EachT, com.github.ajalt.clikt.parameters.options.split.EachT, com.github.ajalt.clikt.parameters.options.split.ValueT)), kotlin.String)/delimiter). |
| [switch](switch.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`RawOption`](-raw-option.md)`.switch(choices: `[`Map`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-map/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, `[`T`](switch.md#T)`>): `[`FlagOption`](-flag-option/index.md)`<`[`T`](switch.md#T)`?>`<br>`fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`RawOption`](-raw-option.md)`.switch(vararg choices: `[`Pair`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-pair/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, `[`T`](switch.md#T)`>): `[`FlagOption`](-flag-option/index.md)`<`[`T`](switch.md#T)`?>`<br>Turn an option into a set of flags that each map to a value. |
| [transformAll](transform-all.md) | `fun <AllT, EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](transform-all.md#EachT)`, `[`ValueT`](transform-all.md#ValueT)`>.transformAll(defaultForHelp: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`? = this.helpTags[HelpFormatter.Tags.DEFAULT], showAsRequired: `[`Boolean`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-boolean/index.html)` = HelpFormatter.Tags.REQUIRED in this.helpTags, transform: `[`CallsTransformer`](-calls-transformer.md)`<`[`EachT`](transform-all.md#EachT)`, `[`AllT`](transform-all.md#AllT)`>): `[`OptionWithValues`](-option-with-values/index.md)`<`[`AllT`](transform-all.md#AllT)`, `[`EachT`](transform-all.md#EachT)`, `[`ValueT`](transform-all.md#ValueT)`>`<br>Transform all calls to the option to the final option type. |
| [transformValues](transform-values.md) | `fun <EachInT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, EachOutT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachInT`](transform-values.md#EachInT)`, `[`ValueT`](transform-values.md#ValueT)`>.transformValues(nvalues: `[`Int`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-int/index.html)`, transform: `[`ArgsTransformer`](-args-transformer.md)`<`[`ValueT`](transform-values.md#ValueT)`, `[`EachOutT`](transform-values.md#EachOutT)`>): `[`NullableOption`](-nullable-option.md)`<`[`EachOutT`](transform-values.md#EachOutT)`, `[`ValueT`](transform-values.md#ValueT)`>`<br>Change the number of values that this option takes. |
| [triple](triple.md) | `fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`NullableOption`](-nullable-option.md)`<`[`EachT`](triple.md#EachT)`, `[`ValueT`](triple.md#ValueT)`>.triple(): `[`NullableOption`](-nullable-option.md)`<`[`Triple`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-triple/index.html)`<`[`ValueT`](triple.md#ValueT)`, `[`ValueT`](triple.md#ValueT)`, `[`ValueT`](triple.md#ValueT)`>, `[`ValueT`](triple.md#ValueT)`>`<br>Change to option to take three values, held in a [Triple](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-triple/index.html). |
| [unique](unique.md) | `fun <EachT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, ValueT> `[`OptionWithValues`](-option-with-values/index.md)`<`[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EachT`](unique.md#EachT)`>, `[`EachT`](unique.md#EachT)`, `[`ValueT`](unique.md#ValueT)`>.unique(): `[`OptionWithValues`](-option-with-values/index.md)`<`[`Set`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)`<`[`EachT`](unique.md#EachT)`>, `[`EachT`](unique.md#EachT)`, `[`ValueT`](unique.md#ValueT)`>`<br>Make the [multiple](multiple.md) option return a unique set of calls |
| [validate](validate.md) | `fun <T : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`> `[`FlagOption`](-flag-option/index.md)`<`[`T`](validate.md#T)`>.validate(validator: `[`OptionValidator`](-option-validator.md)`<`[`T`](validate.md#T)`>): `[`OptionDelegate`](-option-delegate/index.md)`<`[`T`](validate.md#T)`>`<br>`fun <AllT : `[`Any`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-any/index.html)`, EachT, ValueT> `[`OptionWithValues`](-option-with-values/index.md)`<`[`AllT`](validate.md#AllT)`, `[`EachT`](validate.md#EachT)`, `[`ValueT`](validate.md#ValueT)`>.validate(validator: `[`OptionValidator`](-option-validator.md)`<`[`AllT`](validate.md#AllT)`>): `[`OptionDelegate`](-option-delegate/index.md)`<`[`AllT`](validate.md#AllT)`>`<br>Check the final option value and raise an error if it's not valid. |
| [versionOption](version-option.md) | `fun <T : `[`CliktCommand`](../com.github.ajalt.clikt.core/-clikt-command/index.md)`> `[`T`](version-option.md#T)`.versionOption(version: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, help: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "Show the version and exit", names: `[`Set`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-set/index.html)`<`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`> = setOf("--version"), message: (`[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`) -> `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = { "$commandName version $it" }): `[`T`](version-option.md#T)<br>Add an eager option to this command that, when invoked, prints a version message and exits. |
